# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import wds_client
from wds_client.api.instances_api import InstancesApi  # noqa: E501
from wds_client.rest import ApiException


class TestInstancesApi(unittest.TestCase):
    """InstancesApi unit test stubs"""

    def setUp(self):
        self.api = wds_client.api.instances_api.InstancesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_wds_instance(self):
        """Test case for create_wds_instance

        Create an instance  # noqa: E501
        """
        pass

    def test_delete_wds_instance(self):
        """Test case for delete_wds_instance

        Delete an instance  # noqa: E501
        """
        pass

    def test_list_wds_instances(self):
        """Test case for list_wds_instances

        List instances  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
