# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from wds_client.configuration import Configuration


class RequestBodySearch(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'terms': 'str',
        'operator': 'SearchOperator'
    }

    attribute_map = {
        'terms': 'terms',
        'operator': 'operator'
    }

    def __init__(self, terms=None, operator=None, local_vars_configuration=None):  # noqa: E501
        """RequestBodySearch - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._terms = None
        self._operator = None
        self.discriminator = None

        self.terms = terms
        if operator is not None:
            self.operator = operator

    @property
    def terms(self):
        """Gets the terms of this RequestBodySearch.  # noqa: E501

        Space-delimited list of terms on which to search  # noqa: E501

        :return: The terms of this RequestBodySearch.  # noqa: E501
        :rtype: str
        """
        return self._terms

    @terms.setter
    def terms(self, terms):
        """Sets the terms of this RequestBodySearch.

        Space-delimited list of terms on which to search  # noqa: E501

        :param terms: The terms of this RequestBodySearch.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and terms is None:  # noqa: E501
            raise ValueError("Invalid value for `terms`, must not be `None`")  # noqa: E501

        self._terms = terms

    @property
    def operator(self):
        """Gets the operator of this RequestBodySearch.  # noqa: E501


        :return: The operator of this RequestBodySearch.  # noqa: E501
        :rtype: SearchOperator
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this RequestBodySearch.


        :param operator: The operator of this RequestBodySearch.  # noqa: E501
        :type: SearchOperator
        """

        self._operator = operator

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestBodySearch):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RequestBodySearch):
            return True

        return self.to_dict() != other.to_dict()
